#
# spec file for package libfame-0_9-1
#
# Copyright (c) 2023 Packman Team <packman@links2linux.de>
# Copyright (c) 2012-2013 Stefan Seyfried <seife+obs@b1-systems.com>
# Copyright (c) 2006-2009 Manfred Tremmel <Manfred.Tremmel@iiv.de>
# Copyright (c) 2004 Detlef Reichelt <detlef@dreichtelt.de
# Copyright (c) 2003 Manfred Tremmel <Manfred.Tremmel@iiv.de>
# Copyright (c) 2002 Ralf Corsepius <corsepiu@faw.uni-ulm.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.links2linux.org/
#


%define lib       libfame
%define major     1
%define libname   libfame-0_9-%{major}
Name:           %{libname}
Version:        0.9.1
Release:        1699.7.pm.4
Summary:        Fast Assembly Mpeg Encoding library
Summary(de):    Schnelle Assembler MPEG Encodingbibliothek
License:        LGPL-2.0-or-later
Group:          System/Libraries
URL:            https://fame.sourceforge.net
Source0:        libfame-0.9.1.tar.bz2
Patch0:         libfame-0.9.1-gcc34-1.patch
Patch1:         libfame-0.9.1-underquoted-definition.patch
Patch2:         libfame-0.9.1-fix-includes.patch
Patch3:         libfame-config-rpath.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
Provides:       %{lib} = %{version}-%{release}
Obsoletes:      %{lib} < %{version}-%{release}
Provides:       %{lib}%{major} = %{version}-%{release}
Obsoletes:      %{lib}%{major} < %{version}-%{release}

%description
FAME is a library for fast MPEG encoding.

%description -l de
FAME ist eine Bibliothek für schnelles MPEG-Encoding.

%package -n %{lib}-devel
Summary:        Libraries and include to develop using FAME
Summary(de):    Bibliothek und Includes zum Entwicklen mit FAME
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{libname}-devel = %{version}-%{release}
Obsoletes:      %{libname}-devel < %{version}-%{release}
Provides:       %{lib}%{major}-devel = %{version}-%{release}
Obsoletes:      %{lib}%{major}-devel < %{version}-%{release}

%description -n %{lib}-devel
FAME is a library for fast MPEG encoding.

This is the libraries, include files and other resources you can use
to develop FAME applications.

%description -n %{lib}-devel -l de
FAME ist eine Bibliothek für schnelles MPEG-Encoding.

Dies ist die Bibliothek, Include-Dateien und andere Resourcen die zur
Entwicklung von Anwendungen, die FAME verwenden, benötigt werden.

%prep
%setup -q -n %{lib}-%{version}
%patch -P 0 -p1
%patch -P 1
%patch -P 2 -p1
%patch -P 3

# This is required since the included libtool stuff is too old and breaks
# linking (-lm and -lc functions not found!) on FC5 x86_64.
rm -f acinclude.m4 aclocal.m4
cp -f %{_datadir}/aclocal/libtool.m4 libtool.m4

# automake...
touch ./NEWS ./ChangeLog
autoreconf -fi
%{suse_update_libdir}

%build
CFLAGS="%{optflags}"
export CFLAGS

# Needed for snapshot releases.
if [ ! -f configure ]; then
  ./autogen.sh --prefix=%{_prefix} --libdir=%{_libdir} --mandir=%{_mandir} --includedir=%{_includedir}
fi

%ifarch i686 x86_64 ia32e
%configure --enable-mmx
%else
%configure
%endif

%make_build

%install
%make_install
rm -f %{buildroot}/%{_libdir}/*.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc CHANGES README
%{_libdir}/lib*.so.*

%files -n %{lib}-devel
%{_bindir}/*-config
%{_libdir}/lib*.so
%{_libdir}/lib*.la
%{_includedir}/fame*.h
%{_datadir}/aclocal/*
%{_mandir}/man3/*

%changelog
* Mon Mar 27 2023 Luigi Baldoni <aloisio@gmx.com>
- Fix Tumbleweed build
- Add libfame-config-rpath.patch
- Spec cleanup
* Mon Feb 25 2013 seife+obs@b1-systems.com
- replace %%suse_update_config with autoreconf to fix 12.3 build
* Sat May 19 2012 seife+obs@b1-systems.com
- fix 12.2 build by adding automake/autoconf/libtool and touching
  files in %%prep to make automake happy...
* Sat Aug 22 2009 Manfred.Tremmel@iiv.de
- cleanups where rpmlint wasn't so happy
* Thu Apr 24 2008 Manfred.Tremmel@iiv.de
- some cleanups
* Mon May  8 2006 Manfred.Tremmel@iiv.de
- added a m4 macro patch, sent by Andreas Hanke
* Mon Apr 10 2006 Manfred.Tremmel@iiv.de
- added gcc patch
* Tue Mar 28 2006 Manfred.Tremmel@iiv.de
- don't use -fno-unit-at-a-time for SUSE 10.1 thanks for the
  hint to Philipp Thomas
* Sat Nov 27 2004 Detlef Reichelt <detlef@dreichtelt.de
- rebuild for x86_64
- get new config.sub from /usr/share/automake-1.9/config.sub
- add ./configure  --libdir=/usr/lib64
- add Provides:	libfame-0.9.so.1()(64bit)
* Thu Mar 27 2003 Manfred.Tremmel@iiv.de
- added packman headers
* Mon Oct  7 2002 corsepiu@faw.uni-ulm.de
- changed manpages-directory and other path-corrections
